==> minecraftlegion-0.1.5.tgz: package/BehaviorModules/BehaviorEatFood.js <==
const lodash = require('lodash')
const botWebsocket = require('../modules/botWebsocket')

module.exports = class BehaviorEatFood {
  constructor (bot, targets, foods = []) {
    this.bot = bot
    this.targets = targets
    this.stateName = 'BehaviorEatFood'

    this.priority = 'saturation' // saturation or foodPoints

    // If no food introduced then get all foods
    if (foods.length === 0) {
      const mcData = require('minecraft-data')(bot.version)
      const mcDataFoods = mcData.foodsArray
      this.foods = mcDataFoods.map((item) => item.name)
    } else {
      this.foods = foods
    }

    this.isEating = false
    this.isEndEating = false
  }

  onStateEntered () {
    if (this.bot.food === 20) {
      this.isEndEating = true
    } else {
      this.eat()
    }
  }

  onStateExited () {
    this.isEating = false
    this.isEndEating = false
  }

  eat () {
    this.isEating = true

    // Check if in inventory have food
    const availableFood = this.bot.inventory.items().reduce((validFood, food) => {
      const returnValidFood = [...validFood]
      if (this.foods.includes(food.name)) {
        returnValidFood.push(food)
      }
      return returnValidFood
    }, [])

    if (availableFood.length === 0) {
      botWebsocket.log('No food in inventory ')
      this.isEndEating = true
      return
    }

    let bestFood

    if (this.priority === 'foodPoints') {
      bestFood = availableFood.find((item) => item.foodPoints === lodash.maxBy(availableFood, 'foodPoints'))
    } else {
      bestFood = availableFood.find((item) => item.saturation === lodash.maxBy(availableFood, 'saturation'))
    }

    if (!bestFood) {
      this.isEndEating = true
      return
    }

    this.equipFood(bestFood)
      .then(() => this.consumeFood())
      .then(() => {
        this.isEating = false
        if (!this.bot.food === 20) {
          this.eat()
        } else {
          this.isEndEating = true
        }
      })
      .catch((error) => {
        botWebsocket.log('Error on eat food ' + error)
        this.isEndEating = true
      })
  }

  consumeFood () {
    return new Promise((resolve, reject) => {
      this.bot.consume((error) => {
        if (error) {
          reject(error)
        } else {
          resolve()
        }
      })
    })
  }

  equipFood (food) {
    return new Promise((resolve, reject) => {
      this.bot.equip(food, 'hand', function (error) {
        if (error) {
          reject(error)
        } else {
          resolve()
        }
      })
    })
  }

  isFinished () {
    return this.isEndEating
  }
}

==> minecraftlegion-0.1.8.tgz: package/BehaviorModules/BehaviorEatFood.js <==
const botWebsocket = require('../modules/botWebsocket')

module.exports = class BehaviorEatFood {
  constructor (bot, targets) {
    this.bot = bot
    this.targets = targets
    this.stateName = 'BehaviorEatFood'
    this.isEndEating = false

    this.foods = []
    this.isEating = false
  }

  setFoods (foods) {
    this.foods = foods
  }

  onStateEntered () {
    if (this.bot.food === 20) {
      this.isEndEating = true
    } else {
      this.eat()
    }
  }

  getAllFoods () {
    const mcData = require('minecraft-data')(this.bot.version)
    const mcDataFoods = mcData.foodsArray
    return mcDataFoods.map((item) => item.name)
  }

  onStateExited () {
    this.isEating = false
    this.isEndEating = false
  }

  checkFoodInInventory () {
    return this.bot.inventory.items().reduce((validFood, foodInventory) => {
      const returnValidFood = [...validFood]

      const priority = this.foods.findIndex(food => food === foodInventory.name)

      if (priority >= 0) {
        const validFoodWithPriority = {
          ...foodInventory,
          priority
        }
        returnValidFood.push(validFoodWithPriority)
      }

      return returnValidFood
    }, [])
  }

  eat () {
    this.isEating = true

    const availableFood = this.checkFoodInInventory().sort(function (a, b) {
      if (a.priority > b.priority) {
        return 1
      }
      if (a.priority < b.priority) {
        return -1
      }
      return 0
    })

    if (availableFood.length === 0) {
      botWebsocket.log('No food in inventory ')
      this.isEndEating = true
      return
    }

    const firstFoodFound = availableFood.shift()

    if (!firstFoodFound) {
      this.isEndEating = true
      return
    }

    this.equipFood(firstFoodFound)
      .then(() => this.consumeFood())
      .then(() => {
        this.isEating = false
        if (!this.bot.food === 20) {
          this.eat()
        } else {
          this.isEndEating = true
        }
      })
      .catch((error) => {
        botWebsocket.log('Error on eat food ' + error)
        setTimeout(() => {
          this.isEndEating = true
        }, 500)
      })
  }

  consumeFood () {
    return new Promise((resolve, reject) => {
      this.bot.consume((error) => {
        if (error) {
          reject(error)
        } else {
          resolve()
        }
      })
    })
  }

  equipFood (food) {
    return new Promise((resolve, reject) => {
      this.bot.equip(food, 'hand', function (error) {
        if (error) {
          reject(error)
        } else {
          resolve()
        }
      })
    })
  }

  isFinished () {
    return this.isEndEating
  }
}
